/******************************************************************************
 *
 * Copyright (c) 1999 Palm Computing, Inc. or its subsidiaries.
 * All rights reserved.
 *
 * File: MainForm.c
 *
 *****************************************************************************/

#include <PalmOS.h>
#include "StarterRsc.h"
#include "ripoffrom.h"
#include "types.h"
#include "sim.h"
#include "ccpu.h"
#include "games.h"

#define appFileCreator				 'STRT'

UInt8 running = 0;

/***********************************************************************
 *
 * FUNCTION:    MainFormInit
 *
 * DESCRIPTION: This routine initializes the MainForm form.
 *
 * PARAMETERS:  frm - pointer to the MainForm form.
 *
 * RETURNED:    nothing
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
static void MainFormInit(FormPtr /*frmP*/)
{
}


/***********************************************************************
 *
 * FUNCTION:    MainFormDoCommand
 *
 * DESCRIPTION: This routine performs the menu command specified.
 *
 * PARAMETERS:  command  - menu item id
 *
 * RETURNED:    nothing
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
static Boolean MainFormDoCommand(UInt16 command)
{
	Boolean handled = false;
   FormPtr frmP;


	switch (command)
		{
		case MainOptionsAboutStarterApp:
			MenuEraseStatus(0);					// Clear the menu status from the display.
			frmP = FrmInitForm (AboutForm);
			FrmDoDialog (frmP);					// Display the About Box.
			FrmDeleteForm (frmP);
			handled = true;
			break;

		}
	return handled;
}


/***********************************************************************
 *
 * FUNCTION:    MainFormHandleEvent
 *
 * DESCRIPTION: This routine is the event handler for the 
 *              "MainForm" of this application.
 *
 * PARAMETERS:  eventP  - a pointer to an EventType structure
 *
 * RETURNED:    true if the event has handle and should not be passed
 *              to a higher level handler.
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
Boolean MainFormHandleEvent(EventPtr eventP);

Boolean MainFormHandleEvent ( EventPtr eventP ) {
  Boolean handled = false;
  FormPtr frmP = FrmGetActiveForm();

  switch (eventP->eType) {

  case menuEvent:
    return MainFormDoCommand(eventP->data.menu.itemID);

  case frmOpenEvent:
    frmP = FrmGetActiveForm();
    MainFormInit( frmP );
    FrmDrawForm ( frmP );
    handled = true;
    break;

  case ctlSelectEvent:

    switch ( eventP -> data.ctlSelect.controlID ) {

    case MainStartButton:
      handled = true;
      if ( running ) {
	UInt32 current_time;
	UInt8 fps = 0;
	char buffer [ 5 ] = "   ";

	current_time = TimGetSeconds();

	while ( 1 ) {

#if 0
	  if ( bNewFrame ) {
	    RectangleType r;
	    r.topLeft.x = 30;
	    r.topLeft.y = 16;
	    r.extent.x = 60;
	    r.extent.y = 60;
	    WinEraseRectangle ( &r, 0 );
	  }
#endif
	  if ( TimGetSeconds() == current_time ) {
	    fps++;
	  } else {
	    StrPrintF ( buffer, " %d   ", fps );
	    WinDrawChars ( buffer, StrLen ( buffer ), 130, 145 );
	    fps = 0;
	    current_time = TimGetSeconds();
	  }

	  cineExec ( 1000 );

	}

      } else {
	initRipoff();
	cineReset();
	cineExec ( 100000 );
	running = 1;
      }
      break;

    }

    break;

  default:
    break;
		
  }
	
  return ( handled );
}

int update_field ( FormPtr f, int obid, char *newtext ) {
  MemHandle newhandle, oldhandle;
  FieldPtr field;

  newhandle = MemHandleNew ( StrLen ( newtext ) + 1 );

  if ( ! newhandle ) {
    return ( 0 );
  }

  StrCopy ( MemHandleLock ( newhandle ), newtext );
  MemHandleUnlock ( newhandle );

  field = FrmGetObjectPtr ( f,
			    FrmGetObjectIndex ( f, obid ) );

  oldhandle = FldGetTextHandle ( field );

  FldSetTextHandle ( field, newhandle );

  if ( oldhandle ) {
    MemHandleFree ( oldhandle );
  }

  return ( 1 );
}
